(***********************************************************************)
(*                                                                     *)
(*                              Ref-image                              *)
(*                                                                     *)
(*                  Image Segmentation by Refinement                   *)
(*                                                                     *)
(*                       EPI Serena, INRIA Paris                       *)
(*                                                                     *)
(*  Copyright (c) 2009-2017 INRIA.                                     *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Hend Ben Ameur <hbenameur@yahoo.ca>                                *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* Beginning of OCamlGen, 4.2+dev0 generated code. *)

open Segmentation_types_print;;

let printer_dimension ctx ppf = function
  | u_t -> Unatural_print.printer_t ctx ppf u_t
;;

let printer_cutting_choice _ctx ppf = function
  | Configuration_types.All_cuttings ->
    if _ctx = Og_precedence.Ck_argument ||
       _ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,All_cuttings"
  | Configuration_types.Best_cutting ->
    if _ctx = Og_precedence.Ck_argument ||
       _ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,Best_cutting"

and printer_component_choice _ctx ppf = function
  | Configuration_types.All_components ->
    if _ctx = Og_precedence.Ck_argument ||
       _ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,All_components"
  | Configuration_types.Best_component ->
    if _ctx = Og_precedence.Ck_argument ||
       _ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,Best_component"
;;

let printer_dimension_management ctx ppf = function
  | (c, c0) ->
    if ctx = Og_precedence.Ck_record_field then Format.fprintf ppf "%,@ "
      else
    if ctx = Og_precedence.Ck_argument then Format.fprintf ppf "%, (@," else
    if ctx = Og_precedence.Ck_tuple_item then
      Format.fprintf ppf "%,@[<hv 2>(@,";
    Format.fprintf ppf "%,@[<hv 0>";
    printer_cutting_choice Og_precedence.Ck_tuple_item ppf c;
    Format.fprintf ppf "%,,@ ";
    printer_component_choice Og_precedence.Ck_tuple_item ppf c0;
    Format.fprintf ppf "%,@]";
    if ctx = Og_precedence.Ck_argument then Format.fprintf ppf "%,@;<0 -2>)"
      else
    if ctx = Og_precedence.Ck_tuple_item then
      Format.fprintf ppf "%,@;<0 -2>)@]"
;;

let printer_stopping_criterion ctx ppf = function
  | {
      Configuration_types.max_iteration = h_s;
      Configuration_types.min_best_scalar_indicator = f;
      Configuration_types.min_scalar_relative_error = f0;
    } ->
    if ctx = Og_precedence.Ck_argument || ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%, {@ " else
    Format.fprintf ppf "%,@[<hv 2>{@ "; Format.fprintf ppf "%,@[<hv 0>";
    Format.fprintf ppf "%,@[<hv 2>max_iteration =";
    History_types_print.printer_state_number
      Og_precedence.Ck_record_field
      ppf
      h_s;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,@[<hv 2>min_best_scalar_indicator =";
    Og_printer.printer_Float Og_precedence.Ck_record_field ppf f;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,@[<hv 2>min_scalar_relative_error =";
    Og_printer.printer_Float Og_precedence.Ck_record_field ppf f0;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@]";
    if ctx = Og_precedence.Ck_argument || ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%,@;<1 -2>}" else
    Format.fprintf ppf "%,@;<1 -2>}@]"
;;

let printer_t ctx ppf = function
  | {
      Configuration_types.dimension = d;
      Configuration_types.dimension_management = d0;
      Configuration_types.cutting_strategy = c;
      Configuration_types.stopping_criterion = s;
      Configuration_types.image_width = w;
      Configuration_types.image_height = h;
    } ->
    if ctx = Og_precedence.Ck_argument || ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%, {@ " else
    Format.fprintf ppf "%,@[<hv 2>{@ "; Format.fprintf ppf "%,@[<hv 0>";
    Format.fprintf ppf "%,@[<hv 2>dimension =";
    printer_dimension Og_precedence.Ck_record_field ppf d;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,@[<hv 2>dimension_management =";
    printer_dimension_management Og_precedence.Ck_record_field ppf d0;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,@[<hv 2>cutting_strategy =";
    printer_cutting_strategy Og_precedence.Ck_record_field ppf c;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,@[<hv 2>stopping_criterion =";
    printer_stopping_criterion Og_precedence.Ck_record_field ppf s;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,@[<hv 2>image_width =";
    printer_width Og_precedence.Ck_record_field ppf w;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,@[<hv 2>image_height =";
    printer_height Og_precedence.Ck_record_field ppf h;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@]";
    if ctx = Og_precedence.Ck_argument || ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%,@;<1 -2>}" else
    Format.fprintf ppf "%,@;<1 -2>}@]"
;;

let printer_quantity_choice _ctx ppf = function
  | Configuration_types.Param_quantity ->
    if _ctx = Og_precedence.Ck_argument ||
       _ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,Param_quantity"
  | Configuration_types.All_quantities ->
    if _ctx = Og_precedence.Ck_argument ||
       _ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,All_quantities"

and printer_channel_choice _ctx ppf = function
  | Configuration_types.Compound_channel ->
    if _ctx = Og_precedence.Ck_argument ||
       _ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,Compound_channel"
  | Configuration_types.All_channels ->
    if _ctx = Og_precedence.Ck_argument ||
       _ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,All_channels"
;;

let printer_graphics_kind ctx ppf = function
  | (q, c) ->
    if ctx = Og_precedence.Ck_record_field then Format.fprintf ppf "%,@ "
      else
    if ctx = Og_precedence.Ck_argument then Format.fprintf ppf "%, (@," else
    if ctx = Og_precedence.Ck_tuple_item then
      Format.fprintf ppf "%,@[<hv 2>(@,";
    Format.fprintf ppf "%,@[<hv 0>";
    printer_quantity_choice Og_precedence.Ck_tuple_item ppf q;
    Format.fprintf ppf "%,,@ ";
    printer_channel_choice Og_precedence.Ck_tuple_item ppf c;
    Format.fprintf ppf "%,@]";
    if ctx = Og_precedence.Ck_argument then Format.fprintf ppf "%,@;<0 -2>)"
      else
    if ctx = Og_precedence.Ck_tuple_item then
      Format.fprintf ppf "%,@;<0 -2>)@]"
;;

let printer_graphics_mode ctx ppf = function
  | { Configuration_types.on = b; Configuration_types.kind = g_o; } ->
    if ctx = Og_precedence.Ck_argument || ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%, {@ " else
    Format.fprintf ppf "%,@[<hv 2>{@ "; Format.fprintf ppf "%,@[<hv 0>";
    Format.fprintf ppf "%,@[<hv 2>on =";
    Og_printer.printer_Bool Og_precedence.Ck_record_field ppf b;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,@[<hv 2>kind =";
    Og_printer.printer_Option printer_graphics_kind
      Og_precedence.Ck_record_field
      ppf
      g_o;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@]";
    if ctx = Og_precedence.Ck_argument || ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%,@;<1 -2>}" else
    Format.fprintf ppf "%,@;<1 -2>}@]"
;;

let printer_program_configuration ctx ppf = function
  | {
      Configuration_types.formatter = f_f;
      Configuration_types.report_allocated_memory = b;
      Configuration_types.incremental_mode = b0;
      Configuration_types.graphics_mode = g;
      Configuration_types.graphics_window_min_size = s;
      Configuration_types.graphics_window_max_size = s0;
      Configuration_types.graphics_gradient_threshold = u_t;
      Configuration_types.final_image_file_name = u_t0;
    } ->
    if ctx = Og_precedence.Ck_argument || ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%, {@ " else
    Format.fprintf ppf "%,@[<hv 2>{@ "; Format.fprintf ppf "%,@[<hv 0>";
    Format.fprintf ppf "%,@[<hv 2>formatter =";
    Format_print.printer_formatter Og_precedence.Ck_record_field ppf f_f;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,@[<hv 2>report_allocated_memory =";
    Og_printer.printer_Bool Og_precedence.Ck_record_field ppf b;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,@[<hv 2>incremental_mode =";
    Og_printer.printer_Bool Og_precedence.Ck_record_field ppf b0;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,@[<hv 2>graphics_mode =";
    printer_graphics_mode Og_precedence.Ck_record_field ppf g;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,@[<hv 2>graphics_window_min_size =";
    printer_size Og_precedence.Ck_record_field ppf s;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,@[<hv 2>graphics_window_max_size =";
    printer_size Og_precedence.Ck_record_field ppf s0;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,@[<hv 2>graphics_gradient_threshold =";
    Unatural_print.printer_t Og_precedence.Ck_record_field ppf u_t;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,@[<hv 2>final_image_file_name =";
    Ufilename_print.printer_t Og_precedence.Ck_record_field ppf u_t0;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@]";
    if ctx = Og_precedence.Ck_argument || ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%,@;<1 -2>}" else
    Format.fprintf ppf "%,@;<1 -2>}@]"
;;

(* Defining top printers. *)

let print_dimension ppf = printer_dimension Og_precedence.Ck_toplevel ppf
;;

let print_cutting_choice ppf =
  printer_cutting_choice Og_precedence.Ck_toplevel ppf

and print_component_choice ppf =
  printer_component_choice Og_precedence.Ck_toplevel ppf
;;

let print_dimension_management ppf =
  printer_dimension_management Og_precedence.Ck_toplevel ppf
;;

let print_stopping_criterion ppf =
  printer_stopping_criterion Og_precedence.Ck_toplevel ppf
;;

let print_t ppf = printer_t Og_precedence.Ck_toplevel ppf
;;

let print_quantity_choice ppf =
  printer_quantity_choice Og_precedence.Ck_toplevel ppf

and print_channel_choice ppf =
  printer_channel_choice Og_precedence.Ck_toplevel ppf
;;

let print_graphics_kind ppf =
  printer_graphics_kind Og_precedence.Ck_toplevel ppf
;;

let print_graphics_mode ppf =
  printer_graphics_mode Og_precedence.Ck_toplevel ppf
;;

let print_program_configuration ppf =
  printer_program_configuration Og_precedence.Ck_toplevel ppf
;;

(* End of OCamlGen, 4.2+dev0 generated code. *)
