(***********************************************************************)
(*                                                                     *)
(*                              Ref-image                              *)
(*                                                                     *)
(*                  Image Segmentation by Refinement                   *)
(*                                                                     *)
(*                       EPI Serena, INRIA Paris                       *)
(*                                                                     *)
(*  Copyright (c) 2009-2017 INRIA.                                     *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Hend Ben Ameur <hbenameur@yahoo.ca>                                *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* Beginning of OCamlGen, 4.2+dev0 generated code. *)

open Segmentation_types_print;;

let printer_aspect _ctx ppf = function
  | Display_types.Portrait ->
    if _ctx = Og_precedence.Ck_argument ||
       _ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,Portrait"
  | Display_types.Landscape ->
    if _ctx = Og_precedence.Ck_argument ||
       _ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,Landscape"
;;

let printer_direction _ctx ppf = function
  | Display_types.Horizontal ->
    if _ctx = Og_precedence.Ck_argument ||
       _ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,Horizontal"
  | Display_types.Vertical ->
    if _ctx = Og_precedence.Ck_argument ||
       _ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,Vertical"
;;

let printer_rgb_direction _ctx ppf = function
  | Display_types.Rgb_Horizontal ->
    if _ctx = Og_precedence.Ck_argument ||
       _ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,Rgb_Horizontal"
  | Display_types.Rgb_Vertical ->
    if _ctx = Og_precedence.Ck_argument ||
       _ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,Rgb_Vertical"
;;

let rec printer_image_size ctx ppf = function | s -> printer_size ctx ppf s

and printer_display_image_size ctx ppf = function
  | s -> printer_size ctx ppf s

and printer_window_size ctx ppf = function | s -> printer_size ctx ppf s

and printer_min_window_size ctx ppf = function
  | w -> printer_window_size ctx ppf w

and printer_max_window_size ctx ppf = function
  | w -> printer_window_size ctx ppf w
;;

let printer_scaling_factor ctx ppf = function
  | u_t -> Upositive_rational_print.printer_t ctx ppf u_t
;;

let printer_scaling ctx ppf = function
  | f_u_t_u_t ->
    Og_printer.printer_Fun Unatural_print.printer_t Unatural_print.printer_t
      ctx
      ppf
      f_u_t_u_t
;;

let printer_graphics_elements ctx ppf = function
  | {
      Display_types.rgb_direction = r;
      Display_types.scaling_factor = s;
      Display_types.display_image_size = d;
      Display_types.window_size = w;
    } ->
    if ctx = Og_precedence.Ck_argument || ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%, {@ " else
    Format.fprintf ppf "%,@[<hv 2>{@ "; Format.fprintf ppf "%,@[<hv 0>";
    Format.fprintf ppf "%,@[<hv 2>rgb_direction =";
    printer_rgb_direction Og_precedence.Ck_record_field ppf r;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,@[<hv 2>scaling_factor =";
    printer_scaling_factor Og_precedence.Ck_record_field ppf s;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,@[<hv 2>display_image_size =";
    printer_display_image_size Og_precedence.Ck_record_field ppf d;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,@[<hv 2>window_size =";
    printer_window_size Og_precedence.Ck_record_field ppf w;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@]";
    if ctx = Og_precedence.Ck_argument || ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%,@;<1 -2>}" else
    Format.fprintf ppf "%,@;<1 -2>}@]"
;;

let printer_quantity _ctx ppf = function
  | Display_types.Param ->
    if _ctx = Og_precedence.Ck_argument ||
       _ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,Param"
  | Display_types.Data ->
    if _ctx = Og_precedence.Ck_argument ||
       _ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,Data"
  | Display_types.Grad ->
    if _ctx = Og_precedence.Ck_argument ||
       _ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,Grad"
;;

let printer_rgb_compound pp_a ctx ppf = function
  | { Display_types.rgb = (a, a0, a1); Display_types.compound = a2; } ->
    if ctx = Og_precedence.Ck_argument || ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%, {@ " else
    Format.fprintf ppf "%,@[<hv 2>{@ "; Format.fprintf ppf "%,@[<hv 0>";
    Format.fprintf ppf "%,@[<hv 2>rgb ="; Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,@[<hv 0>"; pp_a Og_precedence.Ck_tuple_item ppf a;
    Format.fprintf ppf "%,,@ "; pp_a Og_precedence.Ck_tuple_item ppf a0;
    Format.fprintf ppf "%,,@ "; pp_a Og_precedence.Ck_tuple_item ppf a1;
    Format.fprintf ppf "%,@]"; Format.fprintf ppf "%,;@]";
    Format.fprintf ppf "%,@ "; Format.fprintf ppf "%,@[<hv 2>compound =";
    pp_a Og_precedence.Ck_record_field ppf a2; Format.fprintf ppf "%,;@]";
    Format.fprintf ppf "%,@]";
    if ctx = Og_precedence.Ck_argument || ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%,@;<1 -2>}" else
    Format.fprintf ppf "%,@;<1 -2>}@]"
;;

let printer_pixmap_iter pp_a pp_b ctx ppf = function
  | f_f_z_f_a_z_u_f_a_b_p_u ->
    Og_printer.printer_Fun
      (Og_printer.printer_Fun
         printer_zone_number
         (Og_printer.printer_Fun
            (printer_zc_gimage pp_a)
            Og_printer.printer_Unit))
      (Og_printer.printer_Fun
         (printer_pimage pp_a pp_b)
         Og_printer.printer_Unit)
      ctx
      ppf
      f_f_z_f_a_z_u_f_a_b_p_u

and printer_colormap pp_a ctx ppf = function
  | f_f_c_c_f_a_c ->
    Og_printer.printer_Fun
      (Og_printer.printer_Fun printer_color printer_color)
      (Og_printer.printer_Fun pp_a printer_color)
      ctx
      ppf
      f_f_c_c_f_a_c
;;

let printer_pixmap ctx ppf = function
  | g_p -> Generic_image_print.printer_pixmap ctx ppf g_p

and printer_lower_left_corner ctx ppf = function
  | p -> printer_point ctx ppf p

and printer_print_pixmap ctx ppf = function
  | f_f_f_u ->
    Og_printer.printer_Fun
      Format_print.printer_formatter
      Og_printer.printer_Unit
      ctx
      ppf
      f_f_f_u

and printer_alter_pixmap pp_a pp_b ctx ppf = function
  | f_a_b_p_f_a_c_f_a_g_f_a_b_p_u ->
    Og_printer.printer_Fun
      (printer_pixmap_iter pp_a pp_b)
      (Og_printer.printer_Fun
         (printer_colormap pp_a)
         (Og_printer.printer_Fun
            (printer_gimage pp_a)
            (Og_printer.printer_Fun
               (printer_pimage pp_a pp_b)
               Og_printer.printer_Unit)))
      ctx
      ppf
      f_a_b_p_f_a_c_f_a_g_f_a_b_p_u

and printer_draw_pixmap ctx ppf = function
  | f_u_u ->
    Og_printer.printer_Fun Og_printer.printer_Unit Og_printer.printer_Unit
      ctx
      ppf
      f_u_u
;;

let printer_pixmaps ctx ppf = function
  | p_r -> printer_rgb_compound printer_pixmap ctx ppf p_r

and printer_lower_left_corners ctx ppf = function
  | l_r -> printer_rgb_compound printer_lower_left_corner ctx ppf l_r

and printer_print_pixmaps ctx ppf = function
  | p_r -> printer_rgb_compound printer_print_pixmap ctx ppf p_r

and printer_alter_pixmaps pp_a pp_b ctx ppf = function
  | a_b_a_r ->
    printer_rgb_compound (printer_alter_pixmap pp_a pp_b) ctx ppf a_b_a_r

and printer_draw_pixmaps ctx ppf = function
  | d_r -> printer_rgb_compound printer_draw_pixmap ctx ppf d_r
;;

let printer_display_quantity pp_a pp_b ctx ppf = function
  | {
      Display_types.print_pixmaps = p;
      Display_types.alter_pixmaps = a_b_a;
      Display_types.draw_pixmaps = d;
    } ->
    if ctx = Og_precedence.Ck_argument || ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%, {@ " else
    Format.fprintf ppf "%,@[<hv 2>{@ "; Format.fprintf ppf "%,@[<hv 0>";
    Format.fprintf ppf "%,@[<hv 2>print_pixmaps =";
    printer_print_pixmaps Og_precedence.Ck_record_field ppf p;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,@[<hv 2>alter_pixmaps =";
    printer_alter_pixmaps pp_a pp_b Og_precedence.Ck_record_field ppf a_b_a;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,@[<hv 2>draw_pixmaps =";
    printer_draw_pixmaps Og_precedence.Ck_record_field ppf d;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@]";
    if ctx = Og_precedence.Ck_argument || ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%,@;<1 -2>}" else
    Format.fprintf ppf "%,@;<1 -2>}@]"
;;

let printer_display_quantities pp_a pp_b ctx ppf = function
  | {
      Display_types.dq_param = a_b_d;
      Display_types.dq_data = a_b_d0;
      Display_types.dq_grad = a_b_d1;
    } ->
    if ctx = Og_precedence.Ck_argument || ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%, {@ " else
    Format.fprintf ppf "%,@[<hv 2>{@ "; Format.fprintf ppf "%,@[<hv 0>";
    Format.fprintf ppf "%,@[<hv 2>dq_param =";
    printer_display_quantity pp_a pp_b
      Og_precedence.Ck_record_field
      ppf
      a_b_d;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,@[<hv 2>dq_data =";
    printer_display_quantity pp_a pp_b
      Og_precedence.Ck_record_field
      ppf
      a_b_d0;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,@[<hv 2>dq_grad =";
    printer_display_quantity pp_a pp_b
      Og_precedence.Ck_record_field
      ppf
      a_b_d1;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@]";
    if ctx = Og_precedence.Ck_argument || ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%,@;<1 -2>}" else
    Format.fprintf ppf "%,@;<1 -2>}@]"
;;

(* Defining top printers. *)

let print_aspect ppf = printer_aspect Og_precedence.Ck_toplevel ppf
;;

let print_direction ppf = printer_direction Og_precedence.Ck_toplevel ppf
;;

let print_rgb_direction ppf =
  printer_rgb_direction Og_precedence.Ck_toplevel ppf
;;

let print_image_size ppf = printer_image_size Og_precedence.Ck_toplevel ppf

and print_display_image_size ppf =
  printer_display_image_size Og_precedence.Ck_toplevel ppf

and print_window_size ppf = printer_window_size Og_precedence.Ck_toplevel ppf

and print_min_window_size ppf =
  printer_min_window_size Og_precedence.Ck_toplevel ppf

and print_max_window_size ppf =
  printer_max_window_size Og_precedence.Ck_toplevel ppf
;;

let print_scaling_factor ppf =
  printer_scaling_factor Og_precedence.Ck_toplevel ppf
;;

let print_scaling ppf = printer_scaling Og_precedence.Ck_toplevel ppf
;;

let print_graphics_elements ppf =
  printer_graphics_elements Og_precedence.Ck_toplevel ppf
;;

let print_quantity ppf = printer_quantity Og_precedence.Ck_toplevel ppf
;;

let print_rgb_compound pp_a ppf =
  printer_rgb_compound pp_a Og_precedence.Ck_toplevel ppf
;;

let print_pixmap_iter pp_a pp_b ppf =
  printer_pixmap_iter pp_a pp_b Og_precedence.Ck_toplevel ppf

and print_colormap pp_a ppf =
  printer_colormap pp_a Og_precedence.Ck_toplevel ppf
;;

let print_pixmap ppf = printer_pixmap Og_precedence.Ck_toplevel ppf

and print_lower_left_corner ppf =
  printer_lower_left_corner Og_precedence.Ck_toplevel ppf

and print_print_pixmap ppf =
  printer_print_pixmap Og_precedence.Ck_toplevel ppf

and print_alter_pixmap pp_a pp_b ppf =
  printer_alter_pixmap pp_a pp_b Og_precedence.Ck_toplevel ppf

and print_draw_pixmap ppf = printer_draw_pixmap Og_precedence.Ck_toplevel ppf
;;

let print_pixmaps ppf = printer_pixmaps Og_precedence.Ck_toplevel ppf

and print_lower_left_corners ppf =
  printer_lower_left_corners Og_precedence.Ck_toplevel ppf

and print_print_pixmaps ppf =
  printer_print_pixmaps Og_precedence.Ck_toplevel ppf

and print_alter_pixmaps pp_a pp_b ppf =
  printer_alter_pixmaps pp_a pp_b Og_precedence.Ck_toplevel ppf

and print_draw_pixmaps ppf =
  printer_draw_pixmaps Og_precedence.Ck_toplevel ppf
;;

let print_display_quantity pp_a pp_b ppf =
  printer_display_quantity pp_a pp_b Og_precedence.Ck_toplevel ppf
;;

let print_display_quantities pp_a pp_b ppf =
  printer_display_quantities pp_a pp_b Og_precedence.Ck_toplevel ppf
;;

(* End of OCamlGen, 4.2+dev0 generated code. *)
