(***********************************************************************)
(*                                                                     *)
(*                              Ref-image                              *)
(*                                                                     *)
(*                  Image Segmentation by Refinement                   *)
(*                                                                     *)
(*                       EPI Serena, INRIA Paris                       *)
(*                                                                     *)
(*  Copyright (c) 2009-2017 INRIA.                                     *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Hend Ben Ameur <hbenameur@yahoo.ca>                                *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* Beginning of OCamlGen, 4.2+dev0 generated code. *)

let printer_component_number ctx ppf = function
  | u_t -> Unatural_print.printer_t ctx ppf u_t
;;

let rec printer_length ctx ppf = function
  | u_l -> Upervasives_print.printer_length ctx ppf u_l

and printer_width ctx ppf = function | l -> printer_length ctx ppf l

and printer_height ctx ppf = function | l -> printer_length ctx ppf l

and printer_size ctx ppf = function
  | (w, h) ->
    if ctx = Og_precedence.Ck_record_field then Format.fprintf ppf "%,@ "
      else
    if ctx = Og_precedence.Ck_argument then Format.fprintf ppf "%, (@," else
    if ctx = Og_precedence.Ck_tuple_item then
      Format.fprintf ppf "%,@[<hv 2>(@,";
    Format.fprintf ppf "%,@[<hv 0>";
    printer_width Og_precedence.Ck_tuple_item ppf w;
    Format.fprintf ppf "%,,@ ";
    printer_height Og_precedence.Ck_tuple_item ppf h;
    Format.fprintf ppf "%,@]";
    if ctx = Og_precedence.Ck_argument then Format.fprintf ppf "%,@;<0 -2>)"
      else
    if ctx = Og_precedence.Ck_tuple_item then
      Format.fprintf ppf "%,@;<0 -2>)@]"
;;

let printer_color ctx ppf = function
  | g_c -> Graphics_print.printer_color ctx ppf g_c
;;

let printer_image ctx ppf = function
  | c_u_t -> Umatrix_print.printer_t printer_color ctx ppf c_u_t
;;

let printer_point ctx ppf = function
  | (u_t, u_t0) ->
    if ctx = Og_precedence.Ck_record_field then Format.fprintf ppf "%,@ "
      else
    if ctx = Og_precedence.Ck_argument then Format.fprintf ppf "%, (@," else
    if ctx = Og_precedence.Ck_tuple_item then
      Format.fprintf ppf "%,@[<hv 2>(@,";
    Format.fprintf ppf "%,@[<hv 0>";
    Unatural_print.printer_t Og_precedence.Ck_tuple_item ppf u_t;
    Format.fprintf ppf "%,,@ ";
    Unatural_print.printer_t Og_precedence.Ck_tuple_item ppf u_t0;
    Format.fprintf ppf "%,@]";
    if ctx = Og_precedence.Ck_argument then Format.fprintf ppf "%,@;<0 -2>)"
      else
    if ctx = Og_precedence.Ck_tuple_item then
      Format.fprintf ppf "%,@;<0 -2>)@]"
;;

let printer_gimage pp_a ctx ppf = function
  | a_u_t -> Umatrix_graph_print.printer_t pp_a ctx ppf a_u_t
;;

let printer_indicator pp_a ctx ppf = function | a -> pp_a ctx ppf a
;;

let printer_zone_cutting_candidate pp_a ctx ppf = function
  | { Segmentation_types.indicator = a_i; Segmentation_types.cutting = u_d; } ->
     if ctx = Og_precedence.Ck_argument ||
        ctx = Og_precedence.Ck_record_field
       then Format.fprintf ppf "%, {@ " else
     Format.fprintf ppf "%,@[<hv 2>{@ "; Format.fprintf ppf "%,@[<hv 0>";
     Format.fprintf ppf "%,@[<hv 2>indicator =";
     printer_indicator pp_a Og_precedence.Ck_record_field ppf a_i;
     Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@ ";
     Format.fprintf ppf "%,@[<hv 2>cutting =";
     Umatrix_nonempty_set_print.printer_dichotomy
       Og_precedence.Ck_record_field
       ppf
       u_d;
     Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@]";
     if ctx = Og_precedence.Ck_argument ||
        ctx = Og_precedence.Ck_record_field
       then Format.fprintf ppf "%,@;<1 -2>}" else
     Format.fprintf ppf "%,@;<1 -2>}@]"
;;

let printer_best_zone_cutting pp_a ctx ppf = function
  | Segmentation_types.No_more_zone_cutting ->
    if ctx = Og_precedence.Ck_argument || ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,No_more_zone_cutting"
  | Segmentation_types.Best_zone_cutting a_z ->
    if ctx = Og_precedence.Ck_argument then Format.fprintf ppf "%, (@," else
    if ctx = Og_precedence.Ck_record_field then Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,@[<hv 2>Best_zone_cutting";
    printer_zone_cutting_candidate pp_a Og_precedence.Ck_argument ppf a_z;
    Format.fprintf ppf "%,@]";
    if ctx = Og_precedence.Ck_argument then Format.fprintf ppf "%,@;<0 -2>)"
;;

let printer_cost pp_a ctx ppf = function | a -> pp_a ctx ppf a
;;

let printer_zone_constants pp_a ctx ppf = function
  | { Segmentation_types.zc_param = a; Segmentation_types.zc_cost = a_c; } ->
    if ctx = Og_precedence.Ck_argument || ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%, {@ " else
    Format.fprintf ppf "%,@[<hv 2>{@ "; Format.fprintf ppf "%,@[<hv 0>";
    Format.fprintf ppf "%,@[<hv 2>zc_param =";
    pp_a Og_precedence.Ck_record_field ppf a; Format.fprintf ppf "%,;@]";
    Format.fprintf ppf "%,@ "; Format.fprintf ppf "%,@[<hv 2>zc_cost =";
    printer_cost pp_a Og_precedence.Ck_record_field ppf a_c;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@]";
    if ctx = Og_precedence.Ck_argument || ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%,@;<1 -2>}" else
    Format.fprintf ppf "%,@;<1 -2>}@]"
;;

let printer_zc_gimage pp_a ctx ppf = function
  | a_z_g -> printer_gimage (printer_zone_constants pp_a) ctx ppf a_z_g
;;

let printer_zone pp_a ctx ppf = function
  | a_z_a_b_u_b ->
    Umatrix_structural_mapping_print.printer_block
      (printer_zone_constants pp_a)
      (printer_best_zone_cutting pp_a)
      ctx
      ppf
      a_z_a_b_u_b
;;

let printer_zone_number ctx ppf = function
  | u_b -> Umatrix_structural_mapping_print.printer_block_number ctx ppf u_b
;;

let printer_bounds ctx ppf = function
  | { Segmentation_types.ll = p; Segmentation_types.ur = p0; } ->
    if ctx = Og_precedence.Ck_argument || ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%, {@ " else
    Format.fprintf ppf "%,@[<hv 2>{@ "; Format.fprintf ppf "%,@[<hv 0>";
    Format.fprintf ppf "%,@[<hv 2>ll =";
    printer_point Og_precedence.Ck_record_field ppf p;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,@[<hv 2>ur =";
    printer_point Og_precedence.Ck_record_field ppf p0;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@]";
    if ctx = Og_precedence.Ck_argument || ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%,@;<1 -2>}" else
    Format.fprintf ppf "%,@;<1 -2>}@]"
;;

let printer_pimage pp_a pp_b ctx ppf = function
  | a_z_a_b_b_u_t ->
    Umatrix_structural_mapping_print.printer_t
      (printer_zone_constants pp_a)
      (printer_best_zone_cutting pp_a)
      pp_b
      ctx
      ppf
      a_z_a_b_b_u_t
;;

let printer_cimage pp_a pp_b ctx ppf = function
  | (a_c, a_b_p) ->
    if ctx = Og_precedence.Ck_record_field then Format.fprintf ppf "%,@ "
      else
    if ctx = Og_precedence.Ck_argument then Format.fprintf ppf "%, (@," else
    if ctx = Og_precedence.Ck_tuple_item then
      Format.fprintf ppf "%,@[<hv 2>(@,";
    Format.fprintf ppf "%,@[<hv 0>";
    printer_cost pp_a Og_precedence.Ck_tuple_item ppf a_c;
    Format.fprintf ppf "%,,@ ";
    printer_pimage pp_a pp_b Og_precedence.Ck_tuple_item ppf a_b_p;
    Format.fprintf ppf "%,@]";
    if ctx = Og_precedence.Ck_argument then Format.fprintf ppf "%,@;<0 -2>)"
      else
    if ctx = Og_precedence.Ck_tuple_item then
      Format.fprintf ppf "%,@;<0 -2>)@]"
;;

let printer_zonation pp_a pp_b ctx ppf = function
  | {
      Segmentation_types.component = c;
      Segmentation_types.other_components = c_l;
      Segmentation_types.gimage_data = a_g;
      Segmentation_types.cimage = a_b_c;
    } ->
    if ctx = Og_precedence.Ck_argument || ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%, {@ " else
    Format.fprintf ppf "%,@[<hv 2>{@ "; Format.fprintf ppf "%,@[<hv 0>";
    Format.fprintf ppf "%,@[<hv 2>component =";
    printer_component_number Og_precedence.Ck_record_field ppf c;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,@[<hv 2>other_components =";
    Og_printer.printer_List printer_component_number
      Og_precedence.Ck_record_field
      ppf
      c_l;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,@[<hv 2>gimage_data =";
    printer_gimage pp_a Og_precedence.Ck_record_field ppf a_g;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,@[<hv 2>cimage =";
    printer_cimage pp_a pp_b Og_precedence.Ck_record_field ppf a_b_c;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@]";
    if ctx = Og_precedence.Ck_argument || ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%,@;<1 -2>}" else
    Format.fprintf ppf "%,@;<1 -2>}@]"
;;

let printer_output_status ctx ppf = function
  | Segmentation_types.Max_iteration h_s ->
    if ctx = Og_precedence.Ck_argument then Format.fprintf ppf "%, (@," else
    if ctx = Og_precedence.Ck_record_field then Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,@[<hv 2>Max_iteration";
    History_types_print.printer_state_number
      Og_precedence.Ck_argument
      ppf
      h_s;
    Format.fprintf ppf "%,@]";
    if ctx = Og_precedence.Ck_argument then Format.fprintf ppf "%,@;<0 -2>)"
  | Segmentation_types.Min_scalar_indicator f ->
    if ctx = Og_precedence.Ck_argument then Format.fprintf ppf "%, (@," else
    if ctx = Og_precedence.Ck_record_field then Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,@[<hv 2>Min_scalar_indicator";
    Og_printer.printer_Float Og_precedence.Ck_argument ppf f;
    Format.fprintf ppf "%,@]";
    if ctx = Og_precedence.Ck_argument then Format.fprintf ppf "%,@;<0 -2>)"
  | Segmentation_types.Min_scalar_relative_error f ->
    if ctx = Og_precedence.Ck_argument then Format.fprintf ppf "%, (@," else
    if ctx = Og_precedence.Ck_record_field then Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,@[<hv 2>Min_scalar_relative_error";
    Og_printer.printer_Float Og_precedence.Ck_argument ppf f;
    Format.fprintf ppf "%,@]";
    if ctx = Og_precedence.Ck_argument then Format.fprintf ppf "%,@;<0 -2>)"
  | Segmentation_types.No_more_cuttings ->
    if ctx = Og_precedence.Ck_argument || ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,No_more_cuttings"
;;

let printer_number_of_cuts ctx ppf = function
  | u_t -> Unatural_print.printer_t ctx ppf u_t
;;

let printer_basic_cutting_family _ctx ppf = function
  | Segmentation_types.Horizontal ->
    if _ctx = Og_precedence.Ck_argument ||
       _ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,Horizontal"
  | Segmentation_types.Vertical ->
    if _ctx = Og_precedence.Ck_argument ||
       _ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,Vertical"
;;

let printer_cutting_strategy ctx ppf = function
  | Segmentation_types.Best_in_a_family (n, b_u_l) ->
    if ctx = Og_precedence.Ck_argument then Format.fprintf ppf "%, (@," else
    if ctx = Og_precedence.Ck_record_field then Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,@[<hv 2>Best_in_a_family";
    Format.fprintf ppf "%, (@,"; Format.fprintf ppf "%,@[<hv 0>";
    printer_number_of_cuts Og_precedence.Ck_tuple_item ppf n;
    Format.fprintf ppf "%,,@ ";
    Ulist1_print.printer_list1 printer_basic_cutting_family
      Og_precedence.Ck_tuple_item
      ppf
      b_u_l;
    Format.fprintf ppf "%,@]"; Format.fprintf ppf "%,@;<0 -2>)";
    Format.fprintf ppf "%,@]";
    if ctx = Og_precedence.Ck_argument then Format.fprintf ppf "%,@;<0 -2>)"
  | Segmentation_types.Overall_best ->
    if ctx = Og_precedence.Ck_argument || ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,Overall_best"
;;

let printer_cutting pp_a ctx ppf = function
  | f_c_f_a_g_f_a_z_a_b ->
    Og_printer.printer_Fun
      printer_cutting_strategy
      (Og_printer.printer_Fun
         (printer_gimage pp_a)
         (Og_printer.printer_Fun
            (printer_zc_gimage pp_a)
            (printer_best_zone_cutting pp_a)))
      ctx
      ppf
      f_c_f_a_g_f_a_z_a_b
;;

let printer_component_cutting_candidate pp_a ctx ppf = function
  | {
      Segmentation_types.zone_number = z;
      Segmentation_types.zone_cutting_candidate = a_z;
    } ->
    if ctx = Og_precedence.Ck_argument || ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%, {@ " else
    Format.fprintf ppf "%,@[<hv 2>{@ "; Format.fprintf ppf "%,@[<hv 0>";
    Format.fprintf ppf "%,@[<hv 2>zone_number =";
    printer_zone_number Og_precedence.Ck_record_field ppf z;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,@[<hv 2>zone_cutting_candidate =";
    printer_zone_cutting_candidate pp_a Og_precedence.Ck_record_field ppf a_z;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@]";
    if ctx = Og_precedence.Ck_argument || ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%,@;<1 -2>}" else
    Format.fprintf ppf "%,@;<1 -2>}@]"
;;

let printer_best_component_cutting pp_a ctx ppf = function
  | Segmentation_types.No_more_component_cutting ->
    if ctx = Og_precedence.Ck_argument || ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,No_more_component_cutting"
  | Segmentation_types.Best_component_cutting a_c ->
    if ctx = Og_precedence.Ck_argument then Format.fprintf ppf "%, (@," else
    if ctx = Og_precedence.Ck_record_field then Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,@[<hv 2>Best_component_cutting";
    printer_component_cutting_candidate pp_a
      Og_precedence.Ck_argument
      ppf
      a_c;
    Format.fprintf ppf "%,@]";
    if ctx = Og_precedence.Ck_argument then Format.fprintf ppf "%,@;<0 -2>)"
;;

let printer_global_cutting_candidate pp_a ctx ppf = function
  | {
      Segmentation_types.component_number = c;
      Segmentation_types.component_cutting_candidate = a_c;
    } ->
    if ctx = Og_precedence.Ck_argument || ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%, {@ " else
    Format.fprintf ppf "%,@[<hv 2>{@ "; Format.fprintf ppf "%,@[<hv 0>";
    Format.fprintf ppf "%,@[<hv 2>component_number =";
    printer_component_number Og_precedence.Ck_record_field ppf c;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,@[<hv 2>component_cutting_candidate =";
    printer_component_cutting_candidate pp_a
      Og_precedence.Ck_record_field
      ppf
      a_c;
    Format.fprintf ppf "%,;@]"; Format.fprintf ppf "%,@]";
    if ctx = Og_precedence.Ck_argument || ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%,@;<1 -2>}" else
    Format.fprintf ppf "%,@;<1 -2>}@]"
;;

let printer_best_global_cutting pp_a ctx ppf = function
  | Segmentation_types.No_more_global_cutting ->
    if ctx = Og_precedence.Ck_argument || ctx = Og_precedence.Ck_record_field
      then Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,No_more_global_cutting"
  | Segmentation_types.Best_global_cutting a_g ->
    if ctx = Og_precedence.Ck_argument then Format.fprintf ppf "%, (@," else
    if ctx = Og_precedence.Ck_record_field then Format.fprintf ppf "%,@ ";
    Format.fprintf ppf "%,@[<hv 2>Best_global_cutting";
    printer_global_cutting_candidate pp_a Og_precedence.Ck_argument ppf a_g;
    Format.fprintf ppf "%,@]";
    if ctx = Og_precedence.Ck_argument then Format.fprintf ppf "%,@;<0 -2>)"
;;

(* Defining top printers. *)

let print_component_number ppf =
  printer_component_number Og_precedence.Ck_toplevel ppf
;;

let print_length ppf = printer_length Og_precedence.Ck_toplevel ppf

and print_width ppf = printer_width Og_precedence.Ck_toplevel ppf

and print_height ppf = printer_height Og_precedence.Ck_toplevel ppf

and print_size ppf = printer_size Og_precedence.Ck_toplevel ppf
;;

let print_color ppf = printer_color Og_precedence.Ck_toplevel ppf
;;

let print_image ppf = printer_image Og_precedence.Ck_toplevel ppf
;;

let print_point ppf = printer_point Og_precedence.Ck_toplevel ppf
;;

let print_gimage pp_a ppf = printer_gimage pp_a Og_precedence.Ck_toplevel ppf
;;

let print_indicator pp_a ppf =
  printer_indicator pp_a Og_precedence.Ck_toplevel ppf
;;

let print_zone_cutting_candidate pp_a ppf =
  printer_zone_cutting_candidate pp_a Og_precedence.Ck_toplevel ppf
;;

let print_best_zone_cutting pp_a ppf =
  printer_best_zone_cutting pp_a Og_precedence.Ck_toplevel ppf
;;

let print_cost pp_a ppf = printer_cost pp_a Og_precedence.Ck_toplevel ppf
;;

let print_zone_constants pp_a ppf =
  printer_zone_constants pp_a Og_precedence.Ck_toplevel ppf
;;

let print_zc_gimage pp_a ppf =
  printer_zc_gimage pp_a Og_precedence.Ck_toplevel ppf
;;

let print_zone pp_a ppf = printer_zone pp_a Og_precedence.Ck_toplevel ppf
;;

let print_zone_number ppf = printer_zone_number Og_precedence.Ck_toplevel ppf
;;

let print_bounds ppf = printer_bounds Og_precedence.Ck_toplevel ppf
;;

let print_pimage pp_a pp_b ppf =
  printer_pimage pp_a pp_b Og_precedence.Ck_toplevel ppf
;;

let print_cimage pp_a pp_b ppf =
  printer_cimage pp_a pp_b Og_precedence.Ck_toplevel ppf
;;

let print_zonation pp_a pp_b ppf =
  printer_zonation pp_a pp_b Og_precedence.Ck_toplevel ppf
;;

let print_output_status ppf =
  printer_output_status Og_precedence.Ck_toplevel ppf
;;

let print_number_of_cuts ppf =
  printer_number_of_cuts Og_precedence.Ck_toplevel ppf
;;

let print_basic_cutting_family ppf =
  printer_basic_cutting_family Og_precedence.Ck_toplevel ppf
;;

let print_cutting_strategy ppf =
  printer_cutting_strategy Og_precedence.Ck_toplevel ppf
;;

let print_cutting pp_a ppf =
  printer_cutting pp_a Og_precedence.Ck_toplevel ppf
;;

let print_component_cutting_candidate pp_a ppf =
  printer_component_cutting_candidate pp_a Og_precedence.Ck_toplevel ppf
;;

let print_best_component_cutting pp_a ppf =
  printer_best_component_cutting pp_a Og_precedence.Ck_toplevel ppf
;;

let print_global_cutting_candidate pp_a ppf =
  printer_global_cutting_candidate pp_a Og_precedence.Ck_toplevel ppf
;;

let print_best_global_cutting pp_a ppf =
  printer_best_global_cutting pp_a Og_precedence.Ck_toplevel ppf
;;

(* End of OCamlGen, 4.2+dev0 generated code. *)
