(***********************************************************************)
(*                                                                     *)
(*                                Ulib                                 *)
(*                                                                     *)
(*                   OCaml user's additional library                   *)
(*                                                                     *)
(*                       EPI Serena, INRIA Paris                       *)
(*                                                                     *)
(*  Copyright (c) 2004-2017 INRIA.                                     *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* Beginning of OCamlGen, 4.2+dev0 generated code. *)

let rec printer_xml_t px_a ctx ppf = function
  | a_u_t -> Umatrix_types_print_xml.printer_xml_t px_a ctx ppf a_u_t

and printer_xml_matrix px_a ctx ppf = function
  | a_t -> printer_xml_t px_a ctx ppf a_t
;;

let rec printer_xml_length ctx ppf = function
  | u_l -> Uarray_print_xml.printer_xml_length ctx ppf u_l

and printer_xml_index ctx ppf = function
  | u_i -> Uarray_print_xml.printer_xml_index ctx ppf u_i

and printer_xml_offset ctx ppf = function
  | u_o -> Uarray_print_xml.printer_xml_offset ctx ppf u_o

and printer_xml_line_number ctx ppf = function
  | l -> printer_xml_length ctx ppf l

and printer_xml_column_number ctx ppf = function
  | l -> printer_xml_length ctx ppf l

and printer_xml_line_index ctx ppf = function
  | i -> printer_xml_index ctx ppf i

and printer_xml_column_index ctx ppf = function
  | i -> printer_xml_index ctx ppf i

and printer_xml_cell_index ctx ppf = function
  | i -> printer_xml_index ctx ppf i

and printer_xml_line_offset ctx ppf = function
  | o -> printer_xml_offset ctx ppf o

and printer_xml_column_offset ctx ppf = function
  | o -> printer_xml_offset ctx ppf o
;;

let rec printer_xml_size ctx ppf = function
  | (l, c) ->
    ignore ctx; Format.fprintf ppf "%,@[<hv 2><tuple>@,";
    printer_xml_line_number Og_precedence.Ck_tuple_item ppf l;
    Format.fprintf ppf "%,@,";
    printer_xml_column_number Og_precedence.Ck_tuple_item ppf c;
    Format.fprintf ppf "%,@;<0 -2></tuple>@]"

and printer_xml_index2 ctx ppf = function
  | (l, c) ->
    ignore ctx; Format.fprintf ppf "%,@[<hv 2><tuple>@,";
    printer_xml_line_index Og_precedence.Ck_tuple_item ppf l;
    Format.fprintf ppf "%,@,";
    printer_xml_column_index Og_precedence.Ck_tuple_item ppf c;
    Format.fprintf ppf "%,@;<0 -2></tuple>@]"

and printer_xml_cell ctx ppf = function | i -> printer_xml_index2 ctx ppf i

and printer_xml_offset2 ctx ppf = function
  | (l, c) ->
    ignore ctx; Format.fprintf ppf "%,@[<hv 2><tuple>@,";
    printer_xml_line_offset Og_precedence.Ck_tuple_item ppf l;
    Format.fprintf ppf "%,@,";
    printer_xml_column_offset Og_precedence.Ck_tuple_item ppf c;
    Format.fprintf ppf "%,@;<0 -2></tuple>@]"
;;

(* Defining top printers. *)

let print_xml_t px_a ppf = printer_xml_t px_a Og_precedence.Ck_toplevel ppf

and print_xml_matrix px_a ppf =
  printer_xml_matrix px_a Og_precedence.Ck_toplevel ppf
;;

let print_xml_length ppf = printer_xml_length Og_precedence.Ck_toplevel ppf

and print_xml_index ppf = printer_xml_index Og_precedence.Ck_toplevel ppf

and print_xml_offset ppf = printer_xml_offset Og_precedence.Ck_toplevel ppf

and print_xml_line_number ppf =
  printer_xml_line_number Og_precedence.Ck_toplevel ppf

and print_xml_column_number ppf =
  printer_xml_column_number Og_precedence.Ck_toplevel ppf

and print_xml_line_index ppf =
  printer_xml_line_index Og_precedence.Ck_toplevel ppf

and print_xml_column_index ppf =
  printer_xml_column_index Og_precedence.Ck_toplevel ppf

and print_xml_cell_index ppf =
  printer_xml_cell_index Og_precedence.Ck_toplevel ppf

and print_xml_line_offset ppf =
  printer_xml_line_offset Og_precedence.Ck_toplevel ppf

and print_xml_column_offset ppf =
  printer_xml_column_offset Og_precedence.Ck_toplevel ppf
;;

let print_xml_size ppf = printer_xml_size Og_precedence.Ck_toplevel ppf

and print_xml_index2 ppf = printer_xml_index2 Og_precedence.Ck_toplevel ppf

and print_xml_cell ppf = printer_xml_cell Og_precedence.Ck_toplevel ppf

and print_xml_offset2 ppf = printer_xml_offset2 Og_precedence.Ck_toplevel ppf
;;

(* End of OCamlGen, 4.2+dev0 generated code. *)
