(***********************************************************************)
(*                                                                     *)
(*                                Ulib                                 *)
(*                                                                     *)
(*                   OCaml user's additional library                   *)
(*                                                                     *)
(*                       EPI Serena, INRIA Paris                       *)
(*                                                                     *)
(*  Copyright (c) 2004-2017 INRIA.                                     *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: udelayed_dgraph_types.ml,v 1.5 2017/05/31 15:24:06 fclement Exp $ *)

(* The private type of delayed dynamic graphs. *)

module Nat = Unatural;;
module L = Ulist;;
module Dg = Udynamic_graph;;

let _0_ = Nat._0_;;

let qual = Upervasives.qualify "Udelayed_dgraph";;
let invalid_arg = Upervasives.invalid_arg_qual qual;;

type arrow_number = Dg.arrow_number;;

type 'b delayed_image =
  | Not_yet_computed
  | Image of 'b
;;

type ('a, 'b) delayed_arrow = ('a, 'b delayed_image) Dg.arrow;;

type ('a, 'b, 'c) t =
  {
   f : 'c -> arrow_number -> 'a -> 'b;
   graph : ('a, 'b delayed_image) Dg.t;
   to_do : arrow_number list;
  }
and ('a, 'b, 'c) delayed_dgraph = ('a, 'b, 'c) t
;;

let set ddg i x =
  Dg.set ddg.graph i { Dg.value = x; image = Not_yet_computed; };
  { ddg with to_do = i :: ddg.to_do; }
;;

let set_next ddg = set ddg (Dg.next_unset ddg.graph);;

let make f n x =
  if n = _0_ then invalid_arg "make" "empty delayed graph" else
  let ddg = { f = f; graph = Dg.make n; to_do = []; } in
  set ddg _0_ x
;;

let delay _ = Not_yet_computed;;

let of_values f a =
  let dg = Dg.of_values delay a in
  let len = Dg.next_unset dg in
  let l = L.of_range Nat.pred _0_ len in  (* L.of_range never fails. *)
  { f = f; graph = dg; to_do = l; }
;;

let do_it param ({ f = f; graph = dg; to_do = l; } as ddg) =
  let do_it_f i =
    match Dg.get dg i with
    | ({ Dg.value = x; image = Not_yet_computed; } as ar) ->
        let ar = { ar with Dg.image = Image (f param i x); } in
        Dg.set dg i ar
    | { Dg.image = Image _; _; } -> assert false in
  L.iter do_it_f l;
  { ddg with to_do = []; }
;;
