(***********************************************************************)
(*                                                                     *)
(*                                Ulib                                 *)
(*                                                                     *)
(*                   OCaml user's additional library                   *)
(*                                                                     *)
(*                       EPI Serena, INRIA Paris                       *)
(*                                                                     *)
(*  Copyright (c) 2004-2017 INRIA.                                     *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: unonempty_set_types.mli,v 1.3 2017/05/31 15:24:06 fclement Exp $ *)

(** {3 The private type of nonempty sets} *)

type 'a uindex = 'a Uuniverse.index;;

type 'a index = 'a uindex uindex;;

type 'a t = private
  {
   universe : 'a Uuniverse.t;
   uindices : 'a uindex Uuniverse.t;
  }
and 'a nonempty_set = 'a t
;;

val full : 'a Uuniverse.t -> 'a t;;
val of_array : 'a Uuniverse.t -> 'a uindex array -> 'a t;;
val of_list : 'a Uuniverse.t -> 'a uindex Ulist1.t -> 'a t;;
val union : 'a t -> 'a t -> 'a t;;

(**/**)

val unsafe_of_list : 'a Uuniverse.t -> 'a uindex Ulist1.t -> 'a t;;
val cardinal : 'a t -> Unatural.t;;
val same_universe : 'a t -> 'a t -> bool;;
val check_same_universe : Upervasives.function_name -> 'a t -> 'a t -> unit;;
val fold_left : ('a -> 'b uindex -> 'a) -> 'a -> 'b t -> 'a;;

val invalid_arg : Upervasives.function_name -> Upervasives.message -> 'a;;
val ucheck_index :
  Upervasives.function_name -> 'a Uuniverse.t -> 'a Uuniverse.index -> unit
;;

