(***********************************************************************)
(*                                                                     *)
(*                                Ulib                                 *)
(*                                                                     *)
(*                   OCaml user's additional library                   *)
(*                                                                     *)
(*                       EPI Serena, INRIA Paris                       *)
(*                                                                     *)
(*  Copyright (c) 2004-2017 INRIA.                                     *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: upositive_rational.mli,v 1.9 2017/05/31 15:24:06 fclement Exp $ *)

(** {3 Operations on positive rational numbers} *)

type t = Upositive_rational_types.t = private
  {
   numerator : Unatural.t;
   denominator : Unatural.t;
  }
and positive_rational = t
;;

val of_nat : Unatural.t -> Unatural.t -> t;;

val _1_ : t;;

val scale : t -> Unatural.t -> Unatural.t;;

(** {6 Comparison} *)

val compare : t -> t -> int;;

val equal : t -> t -> bool;;
val different : t -> t -> bool;;
val smaller : t -> t -> bool;;
val greater : t -> t -> bool;;
val smaller_or_equal : t -> t -> bool;;
val greater_or_equal : t -> t -> bool;;

val min : t -> t -> t;;
val max : t -> t -> t;;
