(***********************************************************************)
(*                                                                     *)
(*                                Ulib                                 *)
(*                                                                     *)
(*                   OCaml user's additional library                   *)
(*                                                                     *)
(*                       EPI Serena, INRIA Paris                       *)
(*                                                                     *)
(*  Copyright (c) 2004-2017 INRIA.                                     *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: upositive_rational_types.ml,v 1.12 2017/05/31 15:24:06 fclement Exp $ *)

(* The private type of positive rational numbers. *)

module Nat = Unatural;;

let _0_ = Nat._0_;;

let qual = Upervasives.qualify "Upositive_rational";;
let failwith = Upervasives.failwith_qual qual;;

type t =
  {
   numerator : Nat.t;
   denominator : Nat.t;
  }
and positive_rational = t
;;

let to_t p q =
  if q = _0_ then failwith "of_nat" "zero denominator" else
  if p = _0_ then failwith "of_nat" "zero numerator" else
  let g = Nat.gcd p q in
  { numerator = Nat.div p g; denominator = Nat.div q g; }
;;
