(***********************************************************************)
(*                                                                     *)
(*                                Ulib                                 *)
(*                                                                     *)
(*                   OCaml user's additional library                   *)
(*                                                                     *)
(*                       EPI Serena, INRIA Paris                       *)
(*                                                                     *)
(*  Copyright (c) 2004-2017 INRIA.                                     *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: usubarray_types.ml,v 1.19 2017/05/31 15:24:06 fclement Exp $ *)

(* The private type of subarrays. *)

module Nat = Unatural;;
module A = Uarray;;

let qual = Upervasives.qualify "Usubarray";;
let invalid_arg = Upervasives.invalid_arg_qual qual;;

type length = A.length
and index = A.index
and offset = A.offset
;;

type range =
  {
   offset : offset;
   length : length;
  }
;;

type indices =
  | Range of range
  | Indices of index array
;;

type 'a t =
  {
   support : 'a array;
   indices : indices;
  }
and 'a subarray = 'a t
;;

let range sup ({ offset = ofs; length = len; } as rg) =
  if Nat.add ofs len > A.length sup then
    invalid_arg "range" "subarray exceeds array support" else
  (* Now, we have 0 <= ofs and ofs + len <= length sup.
     Therefore, all indices idx = ofs + i with 0 <= i < len are valid entries
     in the support. *)
  { support = sup; indices = Range rg }
;;

(* What about doubles? *)
let indices sup idxa =
  let len = A.length sup in
  if A.exists (fun idx -> idx > len) idxa then
    invalid_arg "indices" "subarray exceeds array support" else
  (* Now, we have 0 <= idxa.(i) < length sup for all 0 <= i < length idxa.
     Therefore, all indices in idxa are valid entries in the support. *)
  { support = sup; indices = Indices idxa; }
;;
