(***********************************************************************)
(*                                                                     *)
(*                                Ulib                                 *)
(*                                                                     *)
(*                   OCaml user's additional library                   *)
(*                                                                     *)
(*                       EPI Serena, INRIA Paris                       *)
(*                                                                     *)
(*  Copyright (c) 2004-2017 INRIA.                                     *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: uversion.mli,v 1.8 2017/05/31 15:24:06 fclement Exp $ *)

(** {3 Version command option}

 This module is implemented over modules {!Upervasives}, {!Uaref},
 {!Uoption_key}, and {!Ucommand_option} (from the OCaml user's additional
 library Ulib).
 Module {!Upph_id_card} (also from Ulib) provides more convenient features
 for developers of Pph project software. *)

(** {6 Command options} *)

val add_application_version_option :
  Uoption_key.option_keys -> Upervasives.message -> Arg.doc -> unit
(** Add version command options with specified keys and documentation that
 prints the argument message and exit.
 Use this function when the software is an application. *)
;;

val add_library_version_option :
  Uoption_key.option_keys -> Upervasives.message -> Arg.doc -> unit
(** Same as [add_application_version_option] but for libraries. *)
;;

(**/**)
(** {6 Undocumented features} *)

val add_app_long_version_option :
  Uoption_key.option_keys -> Upervasives.message -> Arg.doc -> unit
;;
val add_lib_long_version_option :
  Uoption_key.option_keys -> Upervasives.message -> Arg.doc -> unit
;;
val add_app_version_option :
  Uoption_key.option_keys -> Upervasives.message -> Arg.doc -> unit
;;
val add_lib_version_option :
  Uoption_key.option_keys -> Upervasives.message -> Arg.doc -> unit
;;
val add_app_short_version_option :
  Uoption_key.option_keys -> Upervasives.message -> Arg.doc -> unit
;;
val add_lib_short_version_option :
  Uoption_key.option_keys -> Upervasives.message -> Arg.doc -> unit
;;
